=======
sktutor
=======


.. image:: https://img.shields.io/pypi/v/sktutor.svg
        :target: https://pypi.python.org/pypi/sktutor

.. image:: https://img.shields.io/travis/dfd/sktutor.svg
        :target: https://travis-ci.org/dfd/sktutor

.. image:: https://readthedocs.org/projects/sktutor/badge/?version=latest
        :target: https://sktutor.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/dfd/sktutor/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/dfd/sktutor
        :alt: Code Coverage Status


sktutor helps your machines learn.


* Free software: BSD license
* Documentation: https://sktutor.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

